/***************************************************************************
 * Copyright 2012 by
 *  + Christian-Albrechts-University of Kiel
 *    + Department of Computer Science
 *      + Software Engineering Group 
 *  and others.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ***************************************************************************/

package kieker.webgui.beans.application;

import javax.faces.bean.ApplicationScoped;
import javax.faces.bean.ManagedBean;

import kieker.webgui.beans.IProjectBean;

/**
 * The {@link ForwardBean} is a helper class for navigation purposes only. It allows to navigate between specific pages in a generic matter and is furthermore the
 * reason for the existence of the interface {@link IProjectBean}. The bean has also no properties or fields which could be modified.<br>
 * The bean is an application scoped bean, as there is in its functionality as a utility bean no reason to have more than one instance.
 * 
 * @author Nils Christian Ehmke
 * @version 1.0
 */
@ManagedBean
@ApplicationScoped
public final class ForwardBean {

	/**
	 * Default constructor. <b>Do not use this constructor. This bean is JSF managed.</b>
	 */
	public ForwardBean() {
		// No code necessary.
	}

	/**
	 * This method allows the navigation from one page to another, by saving the project name of the source bean, cleaning the source bean and then setting the
	 * project name of the destination bean. This method then returns the return value of the setter-method of the destination bean. This is usually the next page of
	 * the corresponding bean and can be used to redirect the user.
	 * 
	 * @param sourceBean
	 *            The bean which will be used to get the project name and will be cleared in this method afterwards.
	 * @param destinationBean
	 *            The destination bean whose project name will be set to the saved value and whose return value will be returned.
	 * @return The return value of the destination bean.
	 */
	public String forward(final IProjectBean sourceBean, final IProjectBean destinationBean) {
		// Remember the project name and clean the source bean
		final String projectName = sourceBean.getProjectName();
		sourceBean.clearProject();

		// Set the project of the destination bean and return its return value
		return destinationBean.setProject(projectName);
	}
}
